With this crate, JSON objects and arrays can be transformed in an immutable way, which means
that every “change” leads to a new value. Persistent collections are used internally to make
changes and cloning cheap. Conversions from and to values in the
serde_json crate are provided.
The crate feature jaq enables the transformation of JSON with the
jq language. It is powered by the
jaq engine.